==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1CustomResourceSubresourcesFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1beta1CustomResourceSubresourcesFluentImpl<A extends V1beta1CustomResourceSubresourcesFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1CustomResourceSubresourcesFluent<A>{

    private V1beta1CustomResourceSubresourceScaleBuilder scale;
    private Object status;

    public V1beta1CustomResourceSubresourcesFluentImpl(){
    }
    public V1beta1CustomResourceSubresourcesFluentImpl(V1beta1CustomResourceSubresources instance){
            this.withScale(instance.getScale());

            this.withStatus(instance.getStatus());

    }

    
/**
 * This method has been deprecated, please use method buildScale instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1CustomResourceSubresourceScale getScale(){
            return this.scale!=null?this.scale.build():null;
    }

    public V1beta1CustomResourceSubresourceScale buildScale(){
            return this.scale!=null?this.scale.build():null;
    }

    public A withScale(V1beta1CustomResourceSubresourceScale scale){
            _visitables.remove(this.scale);
            if (scale!=null){ this.scale= new V1beta1CustomResourceSubresourceScaleBuilder(scale); _visitables.add(this.scale);} return (A) this;
    }

    public Boolean hasScale(){
            return this.scale != null;
    }

    public V1beta1CustomResourceSubresourcesFluent.ScaleNested<A> withNewScale(){
            return new ScaleNestedImpl();
    }

    public V1beta1CustomResourceSubresourcesFluent.ScaleNested<A> withNewScaleLike(V1beta1CustomResourceSubresourceScale item){
            return new ScaleNestedImpl(item);
    }

    public V1beta1CustomResourceSubresourcesFluent.ScaleNested<A> editScale(){
            return withNewScaleLike(getScale());
    }

    public V1beta1CustomResourceSubresourcesFluent.ScaleNested<A> editOrNewScale(){
            return withNewScaleLike(getScale() != null ? getScale(): new V1beta1CustomResourceSubresourceScaleBuilder().build());
    }

    public V1beta1CustomResourceSubresourcesFluent.ScaleNested<A> editOrNewScaleLike(V1beta1CustomResourceSubresourceScale item){
            return withNewScaleLike(getScale() != null ? getScale(): item);
    }

    public Object getStatus(){
            return this.status;
    }

    public A withStatus(Object status){
            this.status=status; return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1CustomResourceSubresourcesFluentImpl that = (V1beta1CustomResourceSubresourcesFluentImpl) o;
            if (scale != null ? !scale.equals(that.scale) :that.scale != null) return false;
            if (status != null &&status != this ? !status.equals(that.status) :that.status != null &&status != this ) return false;

            return true;
    }


    public class ScaleNestedImpl<N> extends V1beta1CustomResourceSubresourceScaleFluentImpl<V1beta1CustomResourceSubresourcesFluent.ScaleNested<N>> implements V1beta1CustomResourceSubresourcesFluent.ScaleNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1beta1CustomResourceSubresourceScaleBuilder builder;
    
            ScaleNestedImpl(V1beta1CustomResourceSubresourceScale item){
                    this.builder = new V1beta1CustomResourceSubresourceScaleBuilder(this, item);
            }
            ScaleNestedImpl(){
                    this.builder = new V1beta1CustomResourceSubresourceScaleBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1CustomResourceSubresourcesFluentImpl.this.withScale(builder.build());
    }
    public N endScale(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1CustomResourceSubresourcesFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1beta1CustomResourceSubresourcesFluentImpl<A extends V1beta1CustomResourceSubresourcesFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1CustomResourceSubresourcesFluent<A>{

    private V1beta1CustomResourceSubresourceScaleBuilder scale;
    private Object status;

    public V1beta1CustomResourceSubresourcesFluentImpl(){
    }
    public V1beta1CustomResourceSubresourcesFluentImpl(V1beta1CustomResourceSubresources instance){
            this.withScale(instance.getScale());

            this.withStatus(instance.getStatus());

    }

    
/**
 * This method has been deprecated, please use method buildScale instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1CustomResourceSubresourceScale getScale(){
            return this.scale!=null?this.scale.build():null;
    }

    public V1beta1CustomResourceSubresourceScale buildScale(){
            return this.scale!=null?this.scale.build():null;
    }

    public A withScale(V1beta1CustomResourceSubresourceScale scale){
            _visitables.get("scale").remove(this.scale);
            if (scale!=null){ this.scale= new V1beta1CustomResourceSubresourceScaleBuilder(scale); _visitables.get("scale").add(this.scale);} return (A) this;
    }

    public Boolean hasScale(){
            return this.scale != null;
    }

    public V1beta1CustomResourceSubresourcesFluent.ScaleNested<A> withNewScale(){
            return new ScaleNestedImpl();
    }

    public V1beta1CustomResourceSubresourcesFluent.ScaleNested<A> withNewScaleLike(V1beta1CustomResourceSubresourceScale item){
            return new ScaleNestedImpl(item);
    }

    public V1beta1CustomResourceSubresourcesFluent.ScaleNested<A> editScale(){
            return withNewScaleLike(getScale());
    }

    public V1beta1CustomResourceSubresourcesFluent.ScaleNested<A> editOrNewScale(){
            return withNewScaleLike(getScale() != null ? getScale(): new V1beta1CustomResourceSubresourceScaleBuilder().build());
    }

    public V1beta1CustomResourceSubresourcesFluent.ScaleNested<A> editOrNewScaleLike(V1beta1CustomResourceSubresourceScale item){
            return withNewScaleLike(getScale() != null ? getScale(): item);
    }

    public Object getStatus(){
            return this.status;
    }

    public A withStatus(Object status){
            this.status=status; return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1CustomResourceSubresourcesFluentImpl that = (V1beta1CustomResourceSubresourcesFluentImpl) o;
            if (scale != null ? !scale.equals(that.scale) :that.scale != null) return false;
            if (status != null &&status != this ? !status.equals(that.status) :that.status != null &&status != this ) return false;

            return true;
    }


    public class ScaleNestedImpl<N> extends V1beta1CustomResourceSubresourceScaleFluentImpl<V1beta1CustomResourceSubresourcesFluent.ScaleNested<N>> implements V1beta1CustomResourceSubresourcesFluent.ScaleNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1beta1CustomResourceSubresourceScaleBuilder builder;
    
            ScaleNestedImpl(V1beta1CustomResourceSubresourceScale item){
                    this.builder = new V1beta1CustomResourceSubresourceScaleBuilder(this, item);
            }
            ScaleNestedImpl(){
                    this.builder = new V1beta1CustomResourceSubresourceScaleBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1CustomResourceSubresourcesFluentImpl.this.withScale(builder.build());
    }
    public N endScale(){
            return and();
    }

}


}
